;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "corfu-prescient" "6.3.2"
  "Prescient.el + Corfu."
  '((emacs     "27.1")
    (prescient "6.1.0")
    (corfu     "1.1"))
  :url "https://github.com/radian-software/prescient.el"
  :commit "87e2d2f2ddf24f591a5f70cc90d2afb4537caa18"
  :revdesc "87e2d2f2ddf2"
  :keywords '("extensions")
  :authors '(("Radian LLC" . "contact+prescient@radian.codes"))
  :maintainers '(("Radian LLC" . "contact+prescient@radian.codes")))
